pub struct Pager { /* private fields */ }Expand description
A simple pager implementation. One pager can serve multiple filesystems.
Implementations
Sourceimpl Pager
impl Pager
pub fn new() -> Result<Self, Errno>
Sourcepub fn start_threads(self: &Arc<Self>)
pub fn start_threads(self: &Arc<Self>)
Starts the pager threads.
Sourcepub fn run_pager_thread(&self)
pub fn run_pager_thread(&self)
Dedicated thread responsible for listening on port and supplying pages as needed. More than one pager thread can be running concurrently.