pub fn run_proxy_thread(
new_proxies: Receiver<(ChannelProxy, Arc<LockDepMutex<WakeSources, TerminalLock>>)>,
)Expand description
Starts a thread that listens for new proxies and runs start_proxy on each.
pub fn run_proxy_thread(
new_proxies: Receiver<(ChannelProxy, Arc<LockDepMutex<WakeSources, TerminalLock>>)>,
)Starts a thread that listens for new proxies and runs start_proxy on each.