pub struct SuspendContext {
pub wake_sources: Arc<LockDepMutex<WakeSources, TerminalLock>>,
pub wake_watchers: Arc<LockDepMutex<Vec<EventPair>, TerminalLock>>,
pub node: Node,
pub suspend_duration_histogram: UintExponentialHistogramProperty,
pub suspend_attempts_count: UintProperty,
pub suspend_successes_count: UintProperty,
pub suspend_failures_count: UintProperty,
}Fields
wake_sources: Arc<LockDepMutex<WakeSources, TerminalLock>>wake_watchers: Arc<LockDepMutex<Vec<EventPair>, TerminalLock>>node: NodeInspect node for suspend-related metrics.
suspend_duration_histogram: UintExponentialHistogramPropertyHistogram recording the boot timeline duration (in nanoseconds) of successful container suspensions.
suspend_attempts_count: UintPropertyThe total number of times the container has attempted to suspend.
suspend_successes_count: UintPropertyThe total number of times the container has successfully suspended.
suspend_failures_count: UintPropertyThe total number of times the container has failed to suspend.